import unittest
import vcr
from telemetry.retrieval.graphql_retrieval_strategy import GraphQLRetrievalStrategy

class TestGraphQLRetrievalStrategy(unittest.TestCase):
    pass
    # @vcr.use_cassette('tests/cassettes/test_retrieve_data_with_game_filter.yaml')
    # def test_retrieve_data_with_game_filter(self):
    #     strategy = GraphQLRetrievalStrategy()
    #     filters = ['game']
    #     result = strategy.retrieve_data(filters=filters)
    #     self.assertIsInstance(result, list)
    #     self.assertIsInstance(result[0], dict)
    #     game_names = [game['name'] for game in result]
    #     self.assertIn('iRacing', game_names)
    #     # assert that we have 10 results
    #     self.assertEqual(len(result), 10)

    # @vcr.use_cassette('tests/cassettes/test_retrieve_data_with_session_filter.yaml')
    # def test_retrieve_data_with_session_filter(self):
    #     strategy = GraphQLRetrievalStrategy()
    #     filters = {'session': ['limit', 10]}
    #     result = strategy.retrieve_data(filters=filters)
    #     self.assertIsInstance(result, list)
    #     self.assertIsInstance(result[0], dict)
    #     game_names = [game['name'] for game in result]
    #     self.assertIn('iRacing', game_names)

    # # @vcr.use_cassette('tests/cassettes/test_sessions_group_by_game.yaml')
    # def test_sessions_group_by_game(self):
    #     strategy = GraphQLRetrievalStrategy()
    #     result = strategy.sessions(group_by='game')
    #     self.assertIsInstance(result, list)
    #     self.assertIsInstance(result[0], dict)
    #     game_sessions = {session['telemetryDriverByDriverId']['name']: session for session in result}
    #     self.assertIn('iRacing', game_sessions)
    #     # assert that we have sessions grouped by game
    #     self.assertGreaterEqual(len(game_sessions), 1)



import unittest
from telemetry.retrieval.postgres_retrieval_strategy import PostgresRetrievalStrategy

class TestPostgresRetrievalStrategy(unittest.TestCase):
    def setUp(self):
        self.strategy = PostgresRetrievalStrategy()

    def test_retrieve_data(self):
        query = "SELECT * FROM telemetry_game"  # Example query
        data = self.strategy.retrieve_data(query)
        self.assertIsNotNone(data)

    def test_games(self):
        result = self.strategy.games()
        self.assertIsInstance(result, list)
        game_names = [game.name for game in result]  # Accessing the game name attribute directly
        self.assertIn("iRacing", game_names)

    def test_sessions(self):
        result = self.strategy.sessions(limit=10)
        self.assertEqual(len(result), 10)

    def test_sessions_group_by(self):
        result = self.strategy.sessions(limit=10, group_by="game_id")
        self.assertEqual(len(result), 10)

    def test_sessions_group_by_game(self):
        result = self.strategy.sessions(limit=10, group_by="game")
        self.assertEqual(len(result), 10)

if __name__ == "__main__":
    unittest.main()



import unittest
import vcr
import pandas as pd
from telemetry.retrieval.influx_retrieval_strategy import InfluxRetrievalStrategy

class TestInfluxdbRetrievalStrategy(unittest.TestCase):

    @vcr.use_cassette('tests/cassettes/test_influx_retrieve_session.yaml')
    def test_retrieve_session(self):
        strategy = InfluxRetrievalStrategy()
        filters = 1718114100
        result = strategy.retrieve_data(filters=filters)
        self.assertIsInstance(result, pd.DataFrame)

if __name__ == '__main__':
    unittest.main()
